#[repr(transparent)]pub struct Pasteboard_NotifyType(pub c_uint);Available on crate feature
api-13 only.Expand description
Enumerates the types of data changes that can be observed.
Available since API-level: 13
Tuple Fields
0: c_uintImplementations
Sourceimpl Pasteboard_NotifyType
impl Pasteboard_NotifyType
Sourcepub const LOCAL_DATA_CHANGE: Pasteboard_NotifyType
pub const LOCAL_DATA_CHANGE: Pasteboard_NotifyType
Change of the Pasteboard data in the local device.
Sourcepub const REMOTE_DATA_CHANGE: Pasteboard_NotifyType
pub const REMOTE_DATA_CHANGE: Pasteboard_NotifyType
Change of the Pasteboard data in the remote devices.